@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -34,7 +34,7 @@ public:
     bool startdragImageWithUID(const QStringList &paths, const QString &firstPath = "", bool isCustom = false, const QString &album = "", int UID = -1);
 
     //启动图片展示入口
-    void startImgView(QString currentPath, QStringList paths = QStringList());
+    void startImgView(const QString &currentPath, const QStringList &paths = QStringList());
 
     //设置topbar的显示和隐藏
     void setTopBarVisible(bool visible);
