@@ -19,10 +19,6 @@
 
 #include "image-viewer_global.h"
 
-#ifdef __aarch64__
-#define EnableFFmpegLib 1
-#endif
-
 struct MovieInfo {
     bool valid = false;
     QString filePath = "-";  //文件路径
@@ -82,13 +78,9 @@ private:
 
 private:
     QImage getMovieCover_ffmpegthumbnailer(const QUrl &url, const QString &bufferPath);
-    QImage getMovieCover_gstreamer(const QUrl &url);
-
     MovieInfo getMovieInfo_ffmpeg(const QFileInfo &fi);
     MovieInfo getMovieInfo_mediainfo(const QFileInfo &fi);
-
-    bool checkCommandExist(const QString &command);
-    bool isCrashFormat(const QUrl &url);
+    QImage getMovieCover_ffmpegthumbnailerlib(const QUrl &url);
 
     QMutex m_queuqMutex;
     static MovieService *m_movieService;
@@ -97,11 +89,7 @@ private:
     bool m_ffmpegthumbnailerExist = false;
     QMutex m_bufferMutex;
     std::deque<std::pair<QUrl, MovieInfo>> m_movieInfoBuffer;
-
-#ifdef EnableFFmpegLib
     bool m_ffmpegThumLibExist = false;
-    QImage getMovieCover_ffmpegthumbnailerlib(const QUrl &url);
-#endif
 
     //ffmpeg用
     QString resolutionPattern;
