@@ -1,6 +1,64 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="en">
+<context>
+    <name>AIEnhanceFloatWidget</name>
+    <message>
+        <source>Reprovision</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save as</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AIModelService</name>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image not saved, Do you want to save it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancel</translation>
+    </message>
+    <message>
+        <source>Save as</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image format is not supported, please switch the image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The image resolution exceeds the limit, please switch the image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Portrait not detected, switch pictures.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This file is read-only, please save with another name.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You do not have permission to save files here, please change and retry.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ExtensionPanel</name>
     <message>
@@ -12,6 +70,13 @@
         <translation>Ctrl+I</translation>
     </message>
 </context>
+<context>
+    <name>LibImageGraphicsView</name>
+    <message>
+        <source>AI retouching in progress, please wait...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LibImageInfoWidget</name>
     <message>
@@ -57,6 +122,10 @@
         <source>Favorite</source>
         <translation>Favorite</translation>
     </message>
+    <message>
+        <source>AI retouching</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LockWidget</name>
@@ -236,12 +305,52 @@
     </message>
     <message>
         <source>day</source>
-        <translation>day</translation>
+        <translation type="vanished">day</translation>
     </message>
     <message>
         <source>Photo info</source>
         <translation>Photo info</translation>
     </message>
+    <message>
+        <source>Colorize pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upgrade resolution</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Blurred background</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete background</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hand-drawn cartoons</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2D Manga</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3D Manga</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sketch</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Processing failure.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RenameDialog</name>
