@@ -1,6 +1,64 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_CN">
+<context>
+    <name>AIEnhanceFloatWidget</name>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished">保存</translation>
+    </message>
+    <message>
+        <source>Save as</source>
+        <translation type="unfinished">另存为</translation>
+    </message>
+    <message>
+        <source>Reprovision</source>
+        <translation type="unfinished">重置</translation>
+    </message>
+</context>
+<context>
+    <name>AIModelService</name>
+    <message>
+        <source>Save</source>
+        <translation>保存</translation>
+    </message>
+    <message>
+        <source>Save as</source>
+        <translation type="unfinished">另存为</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">取 消</translation>
+    </message>
+    <message>
+        <source>Image not saved, Do you want to save it?</source>
+        <translation type="unfinished">图片未保存，是否保存？</translation>
+    </message>
+    <message>
+        <source>Image format is not supported, please switch the image.</source>
+        <translation type="unfinished">图像格式不支持，请切换图片。</translation>
+    </message>
+    <message>
+        <source>The image resolution exceeds the limit, please switch the image.</source>
+        <translation type="unfinished">图像分辨率超过限制，请切换图片。</translation>
+    </message>
+    <message>
+        <source>Portrait not detected, switch pictures.</source>
+        <translation type="unfinished">未检测到人像，请切换图片。</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">确定</translation>
+    </message>
+    <message>
+        <source>This file is read-only, please save with another name.</source>
+        <translation type="unfinished">该文件已设置为只读，请使用其他文件名重试。</translation>
+    </message>
+    <message>
+        <source>You do not have permission to save files here, please change and retry.</source>
+        <translation type="unfinished">您没有权限在此路径保存文件，请重试。</translation>
+    </message>
+</context>
 <context>
     <name>ExtensionPanel</name>
     <message>
@@ -12,6 +70,13 @@
         <translation>Ctrl+I</translation>
     </message>
 </context>
+<context>
+    <name>LibImageGraphicsView</name>
+    <message>
+        <source>AI retouching in progress, please wait...</source>
+        <translation type="unfinished">AI修图中，请稍等...</translation>
+    </message>
+</context>
 <context>
     <name>LibImageInfoWidget</name>
     <message>
@@ -57,6 +122,18 @@
         <source>Favorite</source>
         <translation>收藏</translation>
     </message>
+    <message>
+        <source>Reset</source>
+        <translation type="vanished">还原</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="vanished">保存</translation>
+    </message>
+    <message>
+        <source>AI retouching</source>
+        <translation type="unfinished">AI修图</translation>
+    </message>
 </context>
 <context>
     <name>LockWidget</name>
@@ -236,12 +313,52 @@
     </message>
     <message>
         <source>day</source>
-        <translation>天</translation>
+        <translation type="vanished">天</translation>
     </message>
     <message>
         <source>Photo info</source>
         <translation>照片信息</translation>
     </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished">重 试</translation>
+    </message>
+    <message>
+        <source>Colorize pictures</source>
+        <translation type="unfinished">图片上色</translation>
+    </message>
+    <message>
+        <source>Upgrade resolution</source>
+        <translation type="unfinished">提升分辨率</translation>
+    </message>
+    <message>
+        <source>Blurred background</source>
+        <translation type="unfinished">模糊背景</translation>
+    </message>
+    <message>
+        <source>Delete background</source>
+        <translation type="unfinished">删除背景</translation>
+    </message>
+    <message>
+        <source>Hand-drawn cartoons</source>
+        <translation type="unfinished">手绘漫画</translation>
+    </message>
+    <message>
+        <source>2D Manga</source>
+        <translation type="unfinished">2D漫画</translation>
+    </message>
+    <message>
+        <source>Sketch</source>
+        <translation type="unfinished">素描</translation>
+    </message>
+    <message>
+        <source>Processing failure.</source>
+        <translation type="unfinished">处理失败。</translation>
+    </message>
+    <message>
+        <source>3D Manga</source>
+        <translation type="unfinished">3D漫画</translation>
+    </message>
 </context>
 <context>
     <name>RenameDialog</name>
