@@ -16,6 +16,7 @@
 #include <DImageButton>
 #include <DThumbnailProvider>
 #include <DApplicationHelper>
+#include <QMetaObject>
 #include <DSpinner>
 
 #include "imgviewlistview.h"
@@ -377,9 +378,22 @@ void LibBottomToolbar::onTrashBtnClicked()
     if (path.isEmpty() && m_currentpath.isEmpty()) {
         path = m_currentpath;
     }
-    deleteImage();
-    emit ImageEngine::instance()->sigDel(path);
-    //    emit dApp->signalM->deleteByMenu();
+
+    if (LibCommonService::instance()->getImgViewerType() == imageViewerSpace::ImgViewerType::ImgViewerTypeAlbum) {
+        // 相册浏览图片-删除按钮逻辑处理
+#ifdef DELETE_CONFIRM
+        // 新流程，相册会弹出删除确认提示框，点击确认，相册才给imageeditor发送sigDeleteImage信号删除图片
+        emit ImageEngine::instance()->sigDel(path);
+#else
+        // 老流程，直接删除
+        deleteImage();
+        emit ImageEngine::instance()->sigDel(path);
+#endif
+    } else {
+        //本地图片浏览-删除图片，直接删除
+        deleteImage();
+        emit ImageEngine::instance()->sigDel(path);
+    }
 }
 
 void LibBottomToolbar::slotThemeChanged(int type)
@@ -801,6 +815,9 @@ void LibBottomToolbar::initConnection()
     connect(m_imgListWidget, &MyImageListWidget::openImg, this, &LibBottomToolbar::slotOpenImage);
     //删除
     connect(m_trashBtn, &DIconButton::clicked, this, &LibBottomToolbar::onTrashBtnClicked);
+#ifdef DELETE_CONFIRM
+    connect(ImageEngine::instance(), &ImageEngine::sigDeleteImage, this, &LibBottomToolbar::deleteImage);
+#endif
     //ocr
     if (m_ocrIsExists) {
         connect(m_ocrBtn, &DIconButton::clicked, this, &LibBottomToolbar::sigOcr);
