@@ -37,17 +37,24 @@
 #include "slideshow/slideshowpanel.h"
 #include "service/configsetter.h"
 #include "service/imagedataservice.h"
+#include "service/mtpfileproxy.h"
 #include "unionimage/imageutils.h"
+#include "service/aimodelservice.h"
+#include "contents/aienhancefloatwidget.h"
 
-const QString IMAGE_TMPPATH =   QDir::homePath() +
-                                "/.config/deepin/deepin-image-viewer/";
+const QString IMAGE_TMPPATH = QDir::homePath() + "/.config/deepin/deepin-image-viewer/";
 
-const int BOTTOM_TOOLBAR_HEIGHT = 80;   //底部工具看高
-const int BOTTOM_SPACING = 10;          //底部工具栏与底部边缘距离
-const int RT_SPACING = 20;
+const int BOTTOM_TOOLBAR_HEIGHT = 80;  //底部工具看高
+const int BOTTOM_SPACING = 5;          //底部工具栏与底部边缘距离
+const int RT_SPACING = 10;
 const int TOP_TOOLBAR_HEIGHT = 50;
 const int DELAY_HIDE_CURSOR_INTERVAL = 3000;
 
+// 标题栏高度
+const int TITLEBAR_HEIGHT = 50;
+// 紧凑模式下标题栏高度
+const int COMPACT_TITLEBAR_HEIGHT = 40;
+
 using namespace imageViewerSpace;
 
 bool compareByFileInfo(const QFileInfo &str1, const QFileInfo &str2)
@@ -67,6 +74,23 @@ QString ss(const QString &text, const QString &defaultValue)
     return defaultValue;
 }
 
+/**
+   @return 返回当前标题栏高度，紧凑模式和普通模式下的标题栏高度不同
+ */
+int titleBarHeight()
+{
+    // DTK 在 5.6.4 后提供紧凑模式接口，调整控件大小
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::isCompactMode()) {
+        return COMPACT_TITLEBAR_HEIGHT;
+    } else {
+        return TITLEBAR_HEIGHT;
+    }
+#else
+    return TITLEBAR_HEIGHT;
+#endif
+}
+
 LibViewPanel::LibViewPanel(AbstractTopToolbar *customToolbar, QWidget *parent)
     : QFrame(parent)
     , m_topToolbar(customToolbar)
@@ -93,6 +117,11 @@ LibViewPanel::LibViewPanel(AbstractTopToolbar *customToolbar, QWidget *parent)
     initThumbnailWidget();
     initConnect();
 
+    if (AIModelService::instance()->isValid()) {
+        // 创建按钮
+        createAIBtn();
+    }
+
     setAcceptDrops(true);
 //    initExtensionPanel();
 
@@ -243,18 +272,38 @@ void LibViewPanel::initConnect()
 
     m_dirWatcher = new  QFileSystemWatcher(this);
     connect(m_dirWatcher, &QFileSystemWatcher::directoryChanged, this, &LibViewPanel::slotsDirectoryChanged);
+
+    // AI图像增强
+    if (AIModelService::instance()->isValid()) {
+        connect(AIModelService::instance(), &AIModelService::enhanceStart, this, &LibViewPanel::onEnhanceStart);
+        connect(AIModelService::instance(), &AIModelService::enhanceReload, this, &LibViewPanel::onEnhanceReload);
+        connect(AIModelService::instance(), &AIModelService::enhanceEnd, this, &LibViewPanel::onEnhanceEnd);
+    }
+
+    // DTK 在 5.6.4 后提供紧凑模式接口，调整控件大小
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    connect(DGuiApplicationHelper::instance(),
+            &DGuiApplicationHelper::sizeModeChanged,
+            this,
+            [this](DGuiApplicationHelper::SizeMode) {
+                m_topToolbar->resize(width(), titleBarHeight());
+                m_topToolbar->move(0, 0);
+                m_topToolbar->update();
+            });
+#endif
 }
 
 void LibViewPanel::initTopBar()
 {
     //防止在标题栏右键菜单会触发默认的和主窗口的发生
-    if (m_topToolbar == nullptr) { //如果调用者没有指定有效的顶部栏，则使用内置方案
+    if (m_topToolbar == nullptr) {  //如果调用者没有指定有效的顶部栏，则使用内置方案
         m_topToolbar = new LibTopToolbar(false, dynamic_cast<QWidget *>(this->parent()));
         connect(m_topToolbar, &LibTopToolbar::sigLeaveTitle, this, &LibViewPanel::slotBottomMove);
     } else {
         m_topToolbar->setParent(dynamic_cast<QWidget *>(this->parent()));
     }
-    m_topToolbar->resize(width(), 50);
+
+    m_topToolbar->resize(width(), titleBarHeight());
     m_topToolbar->move(0, 0);
     m_topToolbar->setTitleBarTransparent(false);
 }
@@ -311,8 +360,9 @@ void LibViewPanel::initScaleLabel()
 void LibViewPanel::initNavigation()
 {
     m_nav = new NavigationWidget(this);
-    m_nav.setBottomMargin(100);
-    m_nav.setLeftMargin(10);
+    // 导航窗口左下对齐，间距10px
+    m_nav.setBottomMargin(80);
+    m_nav.setLeftMargin(6);
     m_nav.setAnchor(Qt::AnchorLeft, this, Qt::AnchorLeft);
     m_nav.setAnchor(Qt::AnchorBottom, this, Qt::AnchorBottom);
 
@@ -409,15 +459,27 @@ void LibViewPanel::updateMenuContent(const QString &path)
         if (currentPath.isEmpty()) {
             currentPath = m_currentPath;
         }
+
+        // AI增强图片特殊处理，部分选项屏蔽
+        bool enhanceImage = AIModelService::instance()->isTemporaryFile(m_currentPath);
+        if (enhanceImage) {
+            currentPath = m_currentPath;
+        }
+
         QFileInfo info(currentPath);
 
         bool isReadable = info.isReadable() ; //是否可读
-        qDebug() << QFileInfo(info.dir(), info.dir().path()).isWritable();
-        //判断文件是否可写和文件目录是否可写
+        // 判断文件是否可写和文件目录是否可写
         bool isWritable = info.isWritable() && QFileInfo(info.dir(), info.dir().path()).isWritable(); //是否可写
-//        bool isFile = info.isFile(); //是否存在
         bool isRotatable = ImageEngine::instance()->isRotatable(currentPath);//是否可旋转
-        imageViewerSpace::PathType pathType = LibUnionImage_NameSpace::getPathType(currentPath);//路径类型
+        imageViewerSpace::PathType pathType; // 路径类型
+        // 判断是否为MTP文件，现MTP文件将使用代理文件加载
+        if (MtpFileProxy::instance()->contains(currentPath)) {
+            pathType = imageViewerSpace::PathType::PathTypeMTP;
+        } else {
+            pathType = LibUnionImage_NameSpace::getPathType(currentPath);
+        }
+
         imageViewerSpace::ImageType imageType = LibUnionImage_NameSpace::getImageType(currentPath);//图片类型
 
         //判断是否是损坏图片
@@ -467,7 +529,7 @@ void LibViewPanel::updateMenuContent(const QString &path)
         //如果图片数量大于0才能有幻灯片
         appendAction(IdStartSlideShow, QObject::tr("Slide show"), ss("Slide show", "F5"));
         //添加到相册
-        if (isAlbum && isReadable) {
+        if (isAlbum && isReadable && !enhanceImage) {
             //这行代码是在向调用程序寻求album name，根据前面的connect，这里会采用回调的形式执行
             emit ImageEngine::instance()->sigGetAlbumName(ItemInfo.path);
             m_menu->addSeparator();
@@ -513,7 +575,19 @@ void LibViewPanel::updateMenuContent(const QString &path)
             m_menu->addMenu(am);
         }
         m_menu->addSeparator();
-        if (isAlbum && isReadable) {
+
+        // 处理收藏按钮，AI修图的增强图片不允许点击
+        if (isAlbum) {
+            DIconButton *Collection = m_bottomToolbar->getBottomtoolbarButton(imageViewerSpace::ButtonTypeCollection);
+            if (Collection) {
+                Collection->setEnabled(!enhanceImage);
+            }
+        }
+
+        // 添加AI模型选项，仅处理静态图
+        addAIMenu();
+
+        if (isAlbum && isReadable && !enhanceImage) {
             appendAction(IdExport, tr("Export"), ss("Export", "Ctrl+E"));   //导出
         }
         if (isReadable) {
@@ -548,12 +622,12 @@ void LibViewPanel::updateMenuContent(const QString &path)
             TrashButton->setEnabled(false);
         }
         //IdRemoveFromAlbum
-        if (isAlbum && m_isCustomAlbum && isReadable) {
+        if (isAlbum && m_isCustomAlbum && isReadable && !enhanceImage) {
             appendAction(IdRemoveFromAlbum, tr("Remove from album"), ss("Remove from album", ""));
         }
         m_menu->addSeparator();
         //fav
-        if (isAlbum && isReadable) {
+        if (isAlbum && isReadable && !enhanceImage) {
             if (m_isFav) {
                 appendAction(IdRemoveFromFavorites, tr("Unfavorite"), ".");    //取消收藏
             } else {
@@ -586,9 +660,11 @@ void LibViewPanel::updateMenuContent(const QString &path)
 
         }
 
-        //需要判断图片是否支持设置壁纸,todo
-        if (isPic && Libutils::image::imageSupportWallPaper(ItemInfo.path)) {
-            appendAction(IdSetAsWallpaper, QObject::tr("Set as wallpaper"), ss("Set as wallpaper", "Ctrl+F9"));
+        //需要判断图片是否支持设置壁纸，若不支持则置灰设置壁纸菜单项
+        if (isPic) {
+            QAction *ac = appendAction(IdSetAsWallpaper, QObject::tr("Set as wallpaper"), ss("Set as wallpaper", "Ctrl+F9"));
+            if (ac)
+                ac->setEnabled(Libutils::image::imageSupportWallPaper(ItemInfo.path));
         }
         if (isReadable) {
             appendAction(IdDisplayInFileManager, QObject::tr("Display in file manager"),
@@ -678,14 +754,14 @@ void LibViewPanel::showNormal()
     }
     //增加切换全屏和默认大小下方工具栏的移动
     connect(pAn, &QPropertyAnimation::destroyed, this, [ = ] {
-        m_bottomToolbar->move((width() - m_bottomToolbar->width()) / 2, height() - m_bottomToolbar->height() - 10);
+        m_bottomToolbar->move((width() - m_bottomToolbar->width()) / 2, height() - m_bottomToolbar->height() - BOTTOM_SPACING);
         m_bottomToolbar->update();
         //结束时候应该判断一次滑动
         noAnimationBottomMove();
     });
 }
 
-void LibViewPanel::appendAction(int id, const QString &text, const QString &shortcut)
+QAction *LibViewPanel::appendAction(int id, const QString &text, const QString &shortcut)
 {
     if (m_menu && m_menuItemDisplaySwitch.test(static_cast<size_t>(id))) {
         QAction *ac = new QAction(m_menu);
@@ -694,7 +770,11 @@ void LibViewPanel::appendAction(int id, const QString &text, const QString &shor
         ac->setProperty("MenuID", id);
         ac->setShortcut(QKeySequence(shortcut));
         m_menu->addAction(ac);
+
+        return ac;
     }
+
+    return nullptr;
 }
 
 void LibViewPanel::setContextMenuItemVisible(imageViewerSpace::NormalMenuItemId id, bool visible)
@@ -820,8 +900,13 @@ void LibViewPanel::setWallpaper(const QString &imgPath)
 
 bool LibViewPanel::startdragImage(const QStringList &paths, const QString &firstPath)
 {
+    // 若为 MTP 挂载文件，转换为目录加载
+    QStringList realPaths = paths;
+    QString realPath = firstPath;
+    bool isMtpProxy = MtpFileProxy::instance()->checkAndCreateProxyFile(realPaths, realPath);
+
     bool bRet = false;
-    QStringList image_list = paths;
+    QStringList image_list = realPaths;
     if (image_list.isEmpty())
         return false;
 
@@ -833,6 +918,8 @@ bool LibViewPanel::startdragImage(const QStringList &paths, const QString &first
             if (ImageEngine::instance()->isImage(path)) {
                 image_list << path;
             }
+        } else if (isMtpProxy) {
+            // 无需处理，使用默认 image_list
         } else {
             QString DirPath = image_list.first().left(image_list.first().lastIndexOf("/"));
             QDir _dirinit(DirPath);
@@ -881,14 +968,14 @@ bool LibViewPanel::startdragImage(const QStringList &paths, const QString &first
         //stack设置正确位置
         m_stack->setCurrentWidget(m_view);
         //展示当前图片
-        loadImage(firstPath, paths);
-        LibCommonService::instance()->m_listAllPath = paths;
-        LibCommonService::instance()->m_noLoadingPath = paths;
+        loadImage(realPath, realPaths);
+        LibCommonService::instance()->m_listAllPath = realPaths;
+        LibCommonService::instance()->m_noLoadingPath = realPaths;
         LibCommonService::instance()->m_listLoaded.clear();
         //看图首先制作显示的图片的缩略图
-        ImageEngine::instance()->makeImgThumbnail(LibCommonService::instance()->getImgSavePath(), QStringList(firstPath), 1);
+        ImageEngine::instance()->makeImgThumbnail(LibCommonService::instance()->getImgSavePath(), QStringList(realPath), 1);
 
-        loadThumbnails(firstPath);
+        loadThumbnails(realPath);
     }
     m_bottomToolbar->thumbnailMoveCenterWidget();
     return bRet;
@@ -928,7 +1015,7 @@ void LibViewPanel::showTopBottom()
 {
     int nParentWidth = this->width();
     int nParentHeight = this->height();
-    m_bottomToolbar->move(QPoint((nParentWidth - m_bottomToolbar->width()) / 2, nParentHeight - m_bottomToolbar->height() - 10));
+    m_bottomToolbar->move(QPoint((nParentWidth - m_bottomToolbar->width()) / 2, nParentHeight - m_bottomToolbar->height() - BOTTOM_SPACING));
     m_topToolbar->move(QPoint((nParentWidth - m_topToolbar->width()) / 2, 0));
 }
 
@@ -944,7 +1031,7 @@ void LibViewPanel::showAnimationTopBottom()
         QPoint((nParentWidth - m_bottomToolbar->width()) / 2, m_bottomToolbar->y()));
 
     m_bottomAnimation->setEndValue(QPoint((nParentWidth - m_bottomToolbar->width()) / 2,
-                                          nParentHeight - m_bottomToolbar->height() - 10));
+                                          nParentHeight - m_bottomToolbar->height() - BOTTOM_SPACING));
 
     connect(m_bottomAnimation, &QPropertyAnimation::finished, this, [ = ]() {
         delete m_bottomAnimation;
@@ -1042,6 +1129,11 @@ void LibViewPanel::loadThumbnails(const QString &path)
 
 void LibViewPanel::setCurrentWidget(const QString &path)
 {
+    // MTP 挂载文件且在加载中则不进入此判断(加载完成后调用)
+    if (MtpFileProxy::Loading == MtpFileProxy::instance()->state(path)) {
+        return;
+    }
+
     //存在切换到幻灯片被切换回去的情况,所以如果是当前界面为幻灯片,则不切换为其他的页面
     if (m_stack->currentWidget() != m_sliderPanel) {
         QFileInfo info(path);
@@ -1162,12 +1254,17 @@ bool LibViewPanel::startChooseFileDialog()
         QFileInfo firstFileInfo(path);
         LibConfigSetter::instance()->setValue(cfgGroupName, cfgLastOpenPath, firstFileInfo.path());
 
+        // 若为MTP挂载图片，将使用临时目录，需在记录打开目录后执行
+        bool isMtpProxy = MtpFileProxy::instance()->checkAndCreateProxyFile(image_list, path);
+
         if ((path.indexOf("smb-share:server=") != -1 || path.indexOf("mtp:host=") != -1 || path.indexOf("gphoto2:host=") != -1)) {
             image_list.clear();
             //判断是否图片格式
             if (ImageEngine::instance()->isImage(path)) {
                 image_list << path;
             }
+        } else if (isMtpProxy) {
+            // 无需处理，使用默认 image_list
         } else {
             QString DirPath = image_list.first().left(image_list.first().lastIndexOf("/"));
             QDir _dirinit(DirPath);
@@ -1187,17 +1284,20 @@ bool LibViewPanel::startChooseFileDialog()
                 }
             }
         }
-        if (image_list.count() > 0) {
-            bRet = true;
-        } else {
-            bRet = false;
+
+        // Note: 即使传入文件路径，但文件可能被管控无法读取数据，列表为空。
+        if (image_list.isEmpty()) {
+            return false;
         }
+        bRet = true;
+
         QString loadingPath;
         if (image_list.contains(path)) {
             loadingPath = path;
         } else {
             loadingPath = image_list.first();
         }
+
         //stack设置正确位置
         m_stack->setCurrentWidget(m_view);
         //展示当前图片
@@ -1226,14 +1326,14 @@ void LibViewPanel::slotBottomMove()
     if (m_bottomToolbar && m_bottomToolbar->isVisible() && m_topToolbar && m_stack->currentWidget() != m_sliderPanel) {
         if (window()->isFullScreen() || m_ImageOutTitleBar) {
 
-            if ((/*m_stack->currentWidget() != m_sliderPanel &&*/ (((nParentHeight - (10 + m_bottomToolbar->height()) < pos.y() && nParentHeight > pos.y() && nParentHeight == m_bottomToolbar->y()) || (pos.y() < 50 && pos.y() >= 0)) && ((pos.x() > 2)) && (pos.x() < nParentWidth - 2)))) {
+            if ((/*m_stack->currentWidget() != m_sliderPanel &&*/ (((nParentHeight - (BOTTOM_SPACING + m_bottomToolbar->height()) < pos.y() && nParentHeight > pos.y() && nParentHeight == m_bottomToolbar->y()) || (pos.y() < 50 && pos.y() >= 0)) && ((pos.x() > 2)) && (pos.x() < nParentWidth - 2)))) {
                 showAnimationTopBottom();
                 m_isShowTopBottom = true;
             } else if (!m_isShowTopBottom && !window()->isFullScreen()) {
                 showAnimationTopBottom();
-            } else if ((nParentHeight - m_bottomToolbar->height() - 10 > pos.y() &&
-                        nParentHeight - m_bottomToolbar->height() - 10 == m_bottomToolbar->y()) || pos.y() >= nParentHeight || pos.y() <= 0
-                       || pos.x() < 2 || pos.x() > nParentWidth - 2 || (pos.y() > 50 && pos.y() <= nParentHeight - m_bottomToolbar->height() - 10)
+            } else if ((nParentHeight - m_bottomToolbar->height() - BOTTOM_SPACING > pos.y() &&
+                        nParentHeight - m_bottomToolbar->height() - BOTTOM_SPACING == m_bottomToolbar->y()) || pos.y() >= nParentHeight || pos.y() <= 0
+                       || pos.x() < 2 || pos.x() > nParentWidth - 2 || (pos.y() > 50 && pos.y() <= nParentHeight - m_bottomToolbar->height() - BOTTOM_SPACING)
                        /*|| m_stack->currentWidget() == m_sliderPanel*/) {
                 hideAnimationTopBottom();
                 m_isShowTopBottom = true;
@@ -1265,14 +1365,14 @@ void LibViewPanel::noAnimationBottomMove()
 
         if (window()->isFullScreen() || m_ImageOutTitleBar) {
 
-            if ((m_stack->currentWidget() != m_sliderPanel && (((nParentHeight - (10 + m_bottomToolbar->height()) < pos.y() && nParentHeight > pos.y() && nParentHeight == m_bottomToolbar->y()) || (pos.y() < 50 && pos.y() >= 0)) && ((pos.x() > 2)) && (pos.x() < nParentWidth - 2)))) {
+            if ((m_stack->currentWidget() != m_sliderPanel && (((nParentHeight - (BOTTOM_SPACING + m_bottomToolbar->height()) < pos.y() && nParentHeight > pos.y() && nParentHeight == m_bottomToolbar->y()) || (pos.y() < 50 && pos.y() >= 0)) && ((pos.x() > 2)) && (pos.x() < nParentWidth - 2)))) {
                 showTopBottom();
                 m_isShowTopBottom = true;
             } else if (!m_isShowTopBottom && !window()->isFullScreen()) {
                 showTopBottom();
-            } else if ((nParentHeight - m_bottomToolbar->height() - 10 > pos.y() &&
-                        nParentHeight - m_bottomToolbar->height() - 10 == m_bottomToolbar->y()) || pos.y() >= nParentHeight || pos.y() <= 0
-                       || pos.x() < 2 || pos.x() > nParentWidth - 2 || (pos.y() > 50 && pos.y() <= nParentHeight - m_bottomToolbar->height() - 10)
+            } else if ((nParentHeight - m_bottomToolbar->height() - BOTTOM_SPACING > pos.y() &&
+                        nParentHeight - m_bottomToolbar->height() - BOTTOM_SPACING == m_bottomToolbar->y()) || pos.y() >= nParentHeight || pos.y() <= 0
+                       || pos.x() < 2 || pos.x() > nParentWidth - 2 || (pos.y() > 50 && pos.y() <= nParentHeight - m_bottomToolbar->height() - BOTTOM_SPACING)
                        || m_stack->currentWidget() == m_sliderPanel) {
                 hideTopBottom();
                 m_isShowTopBottom = true;
@@ -1568,6 +1668,14 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
             if (m_bottomToolbar) {
                 m_bottomToolbar->setVisible(false);
             }
+
+            // 判断当前是否为AI增强图片，若为则设置为提示是否保存
+            if (AIModelService::instance()->isTemporaryFile(m_currentPath)
+                    && !AIModelService::instance()->isWaitSave()) {
+                AIModelService::instance()->saveFileDialog(m_currentPath, this);
+                resetAIEnhanceImage();
+            }
+
             ViewInfo vinfo;
             vinfo.fullScreen = window()->isFullScreen();
             vinfo.lastPanel = this;
@@ -1581,12 +1689,18 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
             if (m_view) {
                 m_view->slotRotatePixCurrent();
             }
+
             //打开重命名窗口时关闭定时器
             killTimer(m_hideCursorTid);
             m_hideCursorTid = 0;
             m_view->viewport()->setCursor(Qt::ArrowCursor);
 
-            PrintHelper::getIntance()->showPrintDialog(QStringList(m_bottomToolbar->getCurrentItemInfo().path), this);
+            // 判断当前是否为AI增强图片，若为设置增强后的图片
+            if (AIModelService::instance()->isTemporaryFile(m_currentPath)) {
+                PrintHelper::getIntance()->showPrintDialog({m_currentPath}, this);
+            } else {
+                PrintHelper::getIntance()->showPrintDialog(QStringList(m_bottomToolbar->getCurrentItemInfo().path), this);
+            }
 
             // 全屏时，开启定时器，3秒后隐藏鼠标
             if (window()->isFullScreen())
@@ -1647,8 +1761,14 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
             if (m_view) {
                 m_view->slotRotatePixCurrent();
             }
-            //todo,复制
-            Libutils::base::copyImageToClipboard(QStringList(m_bottomToolbar->getCurrentItemInfo().path));
+
+            // 判断当前是否为AI增强图片，若为设置增强后的图片
+            if (AIModelService::instance()->isTemporaryFile(m_currentPath)) {
+                Libutils::base::copyImageToClipboard({m_currentPath});
+            } else {
+                Libutils::base::copyImageToClipboard(QStringList(m_bottomToolbar->getCurrentItemInfo().path));
+            }
+
             break;
         }
         case IdMoveToTrash: {
@@ -1701,8 +1821,12 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
             if (m_view) {
                 m_view->slotRotatePixCurrent();
             }
+            QString path = m_bottomToolbar->getCurrentItemInfo().path;
+            // MTP文件需调整文件路径
+            path = MtpFileProxy::instance()->mapToOriginFile(path);
+
             //todo显示在文管
-            Libutils::base::showInFileManager(m_bottomToolbar->getCurrentItemInfo().path);
+            Libutils::base::showInFileManager(path);
             break;
         }
         case IdImageInfo: {
@@ -1718,6 +1842,7 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
             if (path.isEmpty()) {
                 path = m_currentPath;
             }
+
             m_info->setImagePath(path); //执行强制重刷
             m_info->show();
             m_extensionPanel->setContent(m_info);
@@ -1785,6 +1910,12 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
             emit ImageEngine::instance()->sigUpdateCollectBtn();
             break;
         }
+        case IdImageEnhance: {
+            // 调用进行图片增强
+            int enhanceModel = action->property("EnhanceModel").toInt();
+            triggerImageEnhance(currentpath, enhanceModel);
+            break;
+        }
         default:
             break;
         }
@@ -1855,16 +1986,40 @@ void LibViewPanel::resetBottomToolbarGeometry(bool visible)
 
 void LibViewPanel::openImg(int index, QString path)
 {
+    if (AIModelService::instance()->isValid()) {
+        // 判断当前图片是否为图像增强图片
+        bool previousEnhanced = AIModelService::instance()->isTemporaryFile(m_currentPath);
+        if (previousEnhanced) {
+            if (AIModelService::instance()->isWaitSave()) {
+                return;
+            }
+
+            // 提示是否保存
+            if (!notNeedNotifyEnhanceSave) {
+                AIModelService::instance()->saveFileDialog(m_currentPath, this);
+            }
+        }
+        // 打开其他图片时，清理之前的状态
+        Q_EMIT AIModelService::instance()->clearPreviousEnhance();
+    }
+
     //展示图片
     m_view->slotRotatePixCurrent();
     m_view->setImage(path);
     m_view->resetTransform();
-    QFileInfo info(path);
+
+    bool currentEnhance = AIModelService::instance()->isTemporaryFile(path);
+    setAIBtnVisible(currentEnhance);
+
+    QFileInfo info(AIModelService::instance()->sourceFilePath(path));
     m_topToolbar->setMiddleContent(info.fileName());
+
     m_currentPath = path;
+    if (!currentEnhance) {
+        loadThumbnails(path);
+    }
+
     //刷新收藏按钮
-//    qDebug() << index;
-    loadThumbnails(path);
     emit ImageEngine::instance()->sigUpdateCollectBtn();
     updateMenuContent(path);
 
@@ -1938,7 +2093,7 @@ void LibViewPanel::resizeEvent(QResizeEvent *e)
         }
 
         if (m_topToolbar->isVisible()) {
-            this->m_topToolbar->resize(width(), 50);
+            this->m_topToolbar->resize(width(), titleBarHeight());
         }
     }
 //    resetBottomToolbarGeometry(m_stack->currentWidget() == m_view);
@@ -1948,14 +2103,12 @@ void LibViewPanel::resizeEvent(QResizeEvent *e)
 
     //不需要动画滑动
     noAnimationBottomMove();
-
-
 }
 
 void LibViewPanel::showEvent(QShowEvent *e)
 {
     if (this->m_topToolbar) {
-        m_topToolbar->resize(width(), 50);
+        m_topToolbar->resize(width(), titleBarHeight());
     }
     //显示的时候需要判断一次滑动
     noAnimationBottomMove();
@@ -1984,6 +2137,10 @@ void LibViewPanel::mousePressEvent(QMouseEvent *event)
 
 void LibViewPanel::dragEnterEvent(QDragEnterEvent *event)
 {
+    if (m_AIEnhancing) {
+        return;
+    }
+
     const QMimeData *mimeData = event->mimeData();
     if (!pluginUtils::base::checkMimeData(mimeData)) {
         return;
@@ -2001,6 +2158,10 @@ void LibViewPanel::dragMoveEvent(QDragMoveEvent *event)
 
 void LibViewPanel::dropEvent(QDropEvent *event)
 {
+    if (m_AIEnhancing) {
+        return;
+    }
+
     QList<QUrl> urls = event->mimeData()->urls();
     if (urls.isEmpty()) {
         return;
@@ -2067,3 +2228,219 @@ bool LibViewPanel::eventFilter(QObject *o, QEvent *e)
 
     return QFrame::eventFilter(o, e);
 }
+
+/**
+   @brief 添加AI模型增强选项
+ */
+void LibViewPanel::addAIMenu()
+{
+    if (m_menu && AIModelService::instance()->isValid()) {
+        // 缓存的支持模型列表<名称，模型>
+        QList<QPair<int, QString>> modelList = AIModelService::instance()->supportModel();
+        if (!modelList.isEmpty()) {
+            // Image enhance
+            QMenu *enhanceMenu = m_menu->addMenu(tr("AI retouching"));
+
+            // 模型可能动态变更
+            for (const QPair<int, QString> &model : modelList) {
+                // 命名空间作用，需要指定 QObject::tr() 调用翻译
+                QAction *ac = enhanceMenu->addAction(QObject::tr(model.second.toUtf8().data()));
+                ac->setProperty("MenuID", IdImageEnhance);
+                ac->setProperty("EnhanceModel", model.first);
+            }
+
+            m_menu->addSeparator();
+        }
+    }
+}
+
+/**
+   @brief 创建右侧的AI按钮浮动栏
+ */
+void LibViewPanel::createAIBtn()
+{
+    if (!m_AIFloatBar) {
+        m_AIFloatBar = new AIEnhanceFloatWidget(this);
+
+        connect(m_AIFloatBar, &AIEnhanceFloatWidget::reset, this, &LibViewPanel::resetAIEnhanceImage);
+        connect(m_AIFloatBar, &AIEnhanceFloatWidget::save, this, [this](){
+            AIModelService::instance()->saveEnhanceFile(m_currentPath);
+            resetAIEnhanceImage();
+        });
+        connect(m_AIFloatBar, &AIEnhanceFloatWidget::saveAs, this, [this](){
+            AIModelService::instance()->saveEnhanceFileAs(m_currentPath, this);
+            resetAIEnhanceImage();
+        });
+    }
+}
+
+/**
+   @brief 设置AI按钮浮动栏是否显示
+ */
+void LibViewPanel::setAIBtnVisible(bool visible)
+{
+    if (m_AIFloatBar) {
+        m_AIFloatBar->setVisible(visible);
+    }
+}
+
+/**
+   @brief 触发 \a filePath 图像增强，根据不同选项调用不同模型 \a modelID
+ */
+void LibViewPanel::triggerImageEnhance(const QString &filePath, int modelID)
+{
+    // 判断原文件(可能删除)是否可用
+    QString source = AIModelService::instance()->sourceFilePath(filePath);
+    auto error = AIModelService::instance()->modelEnabled(modelID, source);
+    if (AIModelService::instance()->detectErrorAndNotify(this->parentWidget(), error, filePath)) {
+        return;
+    }
+
+    QString output = AIModelService::instance()->imageProcessing(filePath, modelID, m_view->image());
+    if (output.isEmpty()) {
+        return;
+    }
+    m_view->setImage(output, QImage());
+}
+
+/**
+   @brief 执行图像增强时，根据 \a block 屏蔽界面按钮和快捷键控制
+ */
+void LibViewPanel::blockInputControl(bool block)
+{
+    // 屏蔽工具栏和右键菜单
+    m_bottomToolbar->setEnabled(!block);
+    m_thumbnailWidget->setEnabled(!block);
+
+    if (block) {
+        setContextMenuPolicy(Qt::NoContextMenu);
+        if (m_menu) {
+            m_menu->clear();
+            qDeleteAll(this->actions());
+        }
+    } else {
+        // 右键菜单设置图片将自动刷新
+        setContextMenuPolicy(Qt::CustomContextMenu);
+    }
+
+    // 部分快捷键绑定到 viewpanel , Ctrl+O 绑定在主窗口
+    auto shortcutList = this->findChildren<QShortcut *>("");
+    for (auto shortcut : shortcutList) {
+        shortcut->setEnabled(!block);
+    }
+
+    auto win = window();
+    if (win) {
+        shortcutList = win->findChildren<QShortcut *>("");
+        for (auto shortcut : shortcutList) {
+            shortcut->setEnabled(!block);
+        }
+    }
+}
+
+/**
+   @brief 复位当前AI修图增强的图像
+ */
+void LibViewPanel::resetAIEnhanceImage()
+{
+    if (m_AIFloatBar) {
+        m_AIFloatBar->setVisible(false);
+    }
+
+    // 还原原始图片
+    QString source = AIModelService::instance()->sourceFilePath(m_currentPath);
+
+    notNeedNotifyEnhanceSave = true;
+    openImg(0, source);
+    notNeedNotifyEnhanceSave = false;
+}
+
+/**
+   @brief AI修图图像增强开始，屏蔽界面设置
+ */
+void LibViewPanel::onEnhanceStart()
+{
+    m_AIEnhancing = true;
+
+    // 复位界面，隐藏导航窗口，显示标题/工具栏
+    if (m_nav->isVisible()) {
+        m_nav->setVisible(false);
+    }
+    Q_EMIT m_view->sigImageOutTitleBar(false);
+
+    blockInputControl(true);
+    setAIBtnVisible(false);
+}
+
+/**
+   @brief 接收到 \a output 文件的AI修图重试信号，再次屏蔽界面设置
+ */
+void LibViewPanel::onEnhanceReload(const QString &output)
+{
+    // 仅会处理当前图片，增强失败时会还原为原始文件路径
+    if (m_currentPath != AIModelService::instance()->sourceFilePath(output)) {
+        return;
+    };
+
+    // 设置临时图片
+    m_view->setImage(output, QImage());
+
+    m_AIEnhancing = true;
+
+    blockInputControl(true);
+    setAIBtnVisible(false);
+}
+
+/**
+   @brief AI修图调用结束，根据输出文件 \a output 的增强状态 \a state 判断是否界面替换 \a source 文件展示。
+        若图像增强失败，则会还原为原始的图像文件 \a source 。
+ */
+void LibViewPanel::onEnhanceEnd(const QString &source, const QString &output, int state)
+{
+    // 仅会处理当前图片
+    if (source != AIModelService::instance()->sourceFilePath(m_currentPath)) {
+        if (m_AIEnhancing) {
+            qWarning() << qPrintable("Detect error! receive previous procssing file but still in enhancing state.");
+            blockInputControl(false);
+        }
+        return;
+    };
+
+    QString procPath;
+    AIModelService::Error error = AIModelService::NoError;
+    switch (state) {
+        case AIModelService::LoadSucc: {
+            procPath = output;
+            break;
+        }
+        case AIModelService::LoadFailed: {
+            procPath = source;
+            error = AIModelService::LoadFiledError;
+            break;
+        }
+        case AIModelService::NotDetectPortrait: {
+            procPath = source;
+            error = AIModelService::NotDetectPortraitError;
+            break;
+        }
+        default:
+            // 其它错误，默认还原图片
+            procPath = source;
+            break;
+    }
+
+    // Note: 仅变更了运行时的文件名，而 m_bottomToolbar->getCurrentItemInfo() 的路径信息并未更新
+    notNeedNotifyEnhanceSave = true;
+    openImg(0, procPath);
+    notNeedNotifyEnhanceSave = false;
+
+    blockInputControl(false);
+    m_AIEnhancing = false;
+
+    // 提示信息延后到设置图片后，设置图片时会清理之前的浮动窗口
+    if (AIModelService::NoError != error) {
+        QTimer::singleShot(0, this, [=](){
+            AIModelService::instance()->detectErrorAndNotify(this->parentWidget(), error, output);
+        });
+    }
+}
